@@ -209,8 +209,8 @@ class MediaShowListingView(BrowserView):
         if item.portal_type == 'Image':
             return item.absolute_url()
         
-        #TODO: Added this to avoid the problem with Folders being shown as images and repeated images in the folder and the image itself (what a shity explaination...)
-        return ""
+        #TODO: Added this to avoid the problem with Folders being rendered as images (DELETE THIS WHEN SURE ABOUT THE NEW FIX BELOW)
+        #return ""
         
         catalog = getToolByName(self.context, 'portal_catalog')
         plone_utils = getToolByName(self.context, 'plone_utils')
@@ -228,8 +228,9 @@ class MediaShowListingView(BrowserView):
                     except:
                         return leadMedia.getObject().remoteUrl
                 else:
-                    return leadMedia.getURL()
+                    return ""
             else:
+                #NOTE: Changed this from return leadMedia.getURL() to avoid the problem with Folders being rendered as images
                 return ""
         else:
             #TODO: Add lead image support and News Item Image support
